#addBorderColor.py
#builds a command string for image magick and then passes that command string to image magic via command line
#Following must be done beforehand

#1)  All maps you want to modify must be unpacked in a folder(F). 
#    No other unpacked maps, which you don't want to modify must be in the same folder!!!
#2) run the following command in the windows shell in folder F
#   dir /a:-D/b/s > ListofAllSubFiles.txt
#   it creates a list of all files in all subfolders of folder F
#3) place this file in the folder F
#4) install image magick https://imagemagick.org/script/index.php
#5) run this python script with python 3 installed https://www.python.org/downloads/
#    type addBorderColor_v3.py in command shell(nice debug messages) or double click

#Settings:
ColoredBorder=True 
BorderColor='yellow'   #type 'magick -list color' in the command line for info on colors
BorderTransparency= int(75)  #i.e. 75% transparent border.  can be 0,1,...,100
#------------------------------
import subprocess
import sys

#selects the locations of map.pngs in ListofAllSubFiles.txt and puts them in a list
#uses the same file as highlightNeutralBuildings.py
Filelist=[]
File = open("ListofAllSubFiles.txt", "r")
for locationtext in File:
    if locationtext[-8:]=="map.png\n":
        Filelist.append(locationtext[:-8])
    else:
        continue
File.close()

for location in Filelist:
    print(location)
    MapPreviewFile=location+"map.png"
    
    #READ MAP INFO
    File = open(location+"map.yaml", "r")    
    for line in File:
        LineArray = line.split()
        if len(LineArray)>1 and LineArray[0]=="Bounds:": #get the actual map bounds which define the 0,0 pixels of the map.png
            mapstartx=int(LineArray[1].split(",")[0])
            mapstarty=int(LineArray[1].split(",")[1])
            width=int(LineArray[1].split(",")[2])
            height=int(LineArray[1].split(",")[3])
            MapSize=str(width)+"x"+str(height)
            print(MapSize)
            break
    File.close()
    
    #ADD A COLORED BORDER
    if ColoredBorder:
        #make new background image
        #something like   magick convert -size 100x100 xc:red background.png 
        subprocess.call(['magick','convert','-size',MapSize,'xc:'+str(BorderColor),'background.png'])
   
        #make new bordermask image
        innerarea=' 2,2 '+str(width-3)+','+str(height-3)
        CommandText='fill white rectangle'+innerarea
        #something like magick convert -size 100x100 xc:grey50 -draw "fill white rectangle 2,2 97,97" bordermask.png
        subprocess.call(['magick','convert','-size',MapSize,'xc:grey'+str(BorderTransparency),'-draw',CommandText,'bordermask.png'])
        
        #combine background and map using the transparency(greyscale) of the image bordermask.png
        #something like magick convert background.png map.png bordermask.png -composite 
        subprocess.call(['magick','convert','background.png',MapPreviewFile,'bordermask.png','-composite',MapPreviewFile])

